@@ -135,7 +135,7 @@ def read(input):
     if type(input) is str:
         lines = input.split("\n")
     elif type(input) is List[str]:
-        lines = lines
+        lines = input
     elif type(input) is bytes:
         lines = input.decode("utf-8").split("\n")
 
